PyASq
=====

A pure Python API API.

Compatibility
-------------

PyASq uses attribute annotations, so requires Python 3.6 and up.

Examples
--------

Below is an example of how PyASq could be used to access the
`Random User Generator`_ with a simple interface.

.. literalinclude:: ../examples/random_user.py

.. _Random User Generator: https://randomuser.me/
